==> jc-1.4.0.tar.gz: java/net/URLClassLoader__24JarURLLoader.h <==
// final class java.net.URLClassLoader$JarURLLoader

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d35adbe49818ff1 java_net_URLClassLoader__24JarURLLoader
// @dep_class 10c84e6a4eec2373 java_net_URLClassLoader__24URLLoader

// header file dependencies
// @dep_header java_net_URLClassLoader__24URLLoader

#include "java/net/URLClassLoader__24URLLoader.h"

#ifndef _JC_java_net_URLClassLoader__24JarURLLoader_H_
#define _JC_java_net_URLClassLoader__24JarURLLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader$object;
struct _jc_java_net_URLClassLoader__24Resource$object;
struct _jc_java_util_Vector$object;
struct _jc_java_util_jar_JarFile$object;
struct _jc_java_util_jar_Manifest$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$sub_refs	_jc_java_net_URLClassLoader__24JarURLLoader$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$sub_nonrefs	_jc_java_net_URLClassLoader__24JarURLLoader$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$refs	_jc_java_net_URLClassLoader__24JarURLLoader$refs;
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$nonrefs	_jc_java_net_URLClassLoader__24JarURLLoader$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$object	_jc_java_net_URLClassLoader__24JarURLLoader$object;

typedef const struct _jc_java_net_URLClassLoader__24JarURLLoader$vmethods	_jc_java_net_URLClassLoader__24JarURLLoader$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24JarURLLoader$vtable	_jc_java_net_URLClassLoader__24JarURLLoader$vtable;
typedef const struct _jc_java_net_URLClassLoader__24JarURLLoader$vtype	_jc_java_net_URLClassLoader__24JarURLLoader$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24JarURLLoader$method$_init$4f9d67719ed422b4(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *, struct _jc_java_net_URLClassLoader$object *, struct _jc_java_net_URL$object *);

// Virtual methods
extern struct _jc_java_util_Vector$object *_jc_java_net_URLClassLoader__24JarURLLoader$method$getClassPath$1ee0aa439f6484fa(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *);
extern struct _jc_java_util_jar_Manifest$object *_jc_java_net_URLClassLoader__24JarURLLoader$method$getManifest$eaf02229f23f92a3(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *);
extern struct _jc_java_net_URLClassLoader__24Resource$object *_jc_java_net_URLClassLoader__24JarURLLoader$method$getResource$7e88259a529748c1(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24JarURLLoader$method_info$getClassPath$1ee0aa439f6484fa;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLLoader$method_info$getManifest$eaf02229f23f92a3;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLLoader$method_info$getResource$7e88259a529748c1;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24JarURLLoader$vmethods {
	struct _jc_java_util_Vector$object	*(*getClassPath$1ee0aa439f6484fa)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *);
	struct _jc_java_util_jar_Manifest$object	*(*getManifest$eaf02229f23f92a3)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *);
	struct _jc_java_net_URLClassLoader__24Resource$object	*(*getResource$7e88259a529748c1)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_java_net_URLClassLoader__24JarURLLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24URLLoader$vmethods	java_net_URLClassLoader__24URLLoader;
	_jc_java_net_URLClassLoader__24JarURLLoader$vmethods	java_net_URLClassLoader__24JarURLLoader;
};

// Vtype
struct _jc_java_net_URLClassLoader__24JarURLLoader$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24JarURLLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24JarURLLoader$sub_refs {
	struct _jc_java_util_jar_JarFile$object	*jarfile;
	struct _jc_java_net_URL$object	*baseJarURL;
	struct _jc_java_util_Vector$object	*classPath;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24JarURLLoader$refs {
    _jc_java_net_URLClassLoader__24JarURLLoader$sub_refs	java_net_URLClassLoader__24JarURLLoader;
    _jc_java_net_URLClassLoader__24URLLoader$sub_refs	java_net_URLClassLoader__24URLLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24JarURLLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24JarURLLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24URLLoader$sub_nonrefs	java_net_URLClassLoader__24URLLoader;
    _jc_java_net_URLClassLoader__24JarURLLoader$sub_nonrefs	java_net_URLClassLoader__24JarURLLoader;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24JarURLLoader$object {
	_jc_java_net_URLClassLoader__24JarURLLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24JarURLLoader$vtype	*vtype;
	_jc_java_net_URLClassLoader__24JarURLLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24JarURLLoader$vtype _jc_java_net_URLClassLoader__24JarURLLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24JarURLLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24JarURLLoader$class_object;

#endif	/* _JC_java_net_URLClassLoader__24JarURLLoader_H_ */

==> jc-1.4.6.tar.gz: java/net/URLClassLoader__24JarURLLoader.h <==
// final class java.net.URLClassLoader$JarURLLoader

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d35adbe49818ff1 java_net_URLClassLoader__24JarURLLoader
// @dep_class 10c84e6a4eec2373 java_net_URLClassLoader__24URLLoader

// header file dependencies
// @dep_header java_net_URLClassLoader__24URLLoader

#include "java/net/URLClassLoader__24URLLoader.h"

#ifndef _JC_java_net_URLClassLoader__24JarURLLoader_H_
#define _JC_java_net_URLClassLoader__24JarURLLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader$object;
struct _jc_java_net_URLClassLoader__24Resource$object;
struct _jc_java_util_Vector$object;
struct _jc_java_util_jar_JarFile$object;
struct _jc_java_util_jar_Manifest$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$sub_refs	_jc_java_net_URLClassLoader__24JarURLLoader$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$sub_nonrefs	_jc_java_net_URLClassLoader__24JarURLLoader$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$refs	_jc_java_net_URLClassLoader__24JarURLLoader$refs;
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$nonrefs	_jc_java_net_URLClassLoader__24JarURLLoader$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24JarURLLoader$object	_jc_java_net_URLClassLoader__24JarURLLoader$object;

typedef const struct _jc_java_net_URLClassLoader__24JarURLLoader$vmethods	_jc_java_net_URLClassLoader__24JarURLLoader$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24JarURLLoader$vtable	_jc_java_net_URLClassLoader__24JarURLLoader$vtable;
typedef const struct _jc_java_net_URLClassLoader__24JarURLLoader$vtype	_jc_java_net_URLClassLoader__24JarURLLoader$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24JarURLLoader$method$_init$4f9d67719ed422b4(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *, struct _jc_java_net_URLClassLoader$object *, struct _jc_java_net_URL$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_Vector$object *_jc_java_net_URLClassLoader__24JarURLLoader$method$getClassPath$1ee0aa439f6484fa(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_jar_Manifest$object *_jc_java_net_URLClassLoader__24JarURLLoader$method$getManifest$eaf02229f23f92a3(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URLClassLoader__24Resource$object *_jc_java_net_URLClassLoader__24JarURLLoader$method$getResource$7e88259a529748c1(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24JarURLLoader$method_info$getClassPath$1ee0aa439f6484fa;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLLoader$method_info$getManifest$eaf02229f23f92a3;
extern _jc_method _jc_java_net_URLClassLoader__24JarURLLoader$method_info$getResource$7e88259a529748c1;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24JarURLLoader$vmethods {
	struct _jc_java_util_Vector$object	*(*getClassPath$1ee0aa439f6484fa)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_jar_Manifest$object	*(*getManifest$eaf02229f23f92a3)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URLClassLoader__24Resource$object	*(*getResource$7e88259a529748c1)(_jc_env *, struct _jc_java_net_URLClassLoader__24JarURLLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_URLClassLoader__24JarURLLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24URLLoader$vmethods	java_net_URLClassLoader__24URLLoader;
	_jc_java_net_URLClassLoader__24JarURLLoader$vmethods	java_net_URLClassLoader__24JarURLLoader;
};

// Vtype
struct _jc_java_net_URLClassLoader__24JarURLLoader$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24JarURLLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24JarURLLoader$sub_refs {
	struct _jc_java_util_jar_JarFile$object	*jarfile;
	struct _jc_java_net_URL$object	*baseJarURL;
	struct _jc_java_util_Vector$object	*classPath;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24JarURLLoader$refs {
    _jc_java_net_URLClassLoader__24JarURLLoader$sub_refs	java_net_URLClassLoader__24JarURLLoader;
    _jc_java_net_URLClassLoader__24URLLoader$sub_refs	java_net_URLClassLoader__24URLLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24JarURLLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24JarURLLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24URLLoader$sub_nonrefs	java_net_URLClassLoader__24URLLoader;
    _jc_java_net_URLClassLoader__24JarURLLoader$sub_nonrefs	java_net_URLClassLoader__24JarURLLoader;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24JarURLLoader$object {
	_jc_java_net_URLClassLoader__24JarURLLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24JarURLLoader$vtype	*vtype;
	_jc_java_net_URLClassLoader__24JarURLLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24JarURLLoader$vtype _jc_java_net_URLClassLoader__24JarURLLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24JarURLLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24JarURLLoader$class_object;

#endif	/* _JC_java_net_URLClassLoader__24JarURLLoader_H_ */
